#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author: Sai
# @Date:   2014-02-12 23:30:38
# @Email:  email@example.com
# @Last modified by:   Sai
# @Last modified time: 2014-03-02 20:10:33

from django import forms


class MPConfigForm(forms.Form):
    SinaAppKey = forms.CharField(label="Sina App Key:", max_length=100,
                                 required=False)
    SinaAppSecret = forms.CharField(label="Sina App Secret:", max_length=100,
                                    required=False)
    TencentAppKey = forms.CharField(label="Tencent App Key", max_length=100,
                                    required=False)
    TencentAppSecret = forms.CharField(label="Tencent App Secret",
                                       max_length=100, required=False)
    Domain = forms.CharField(label="MoePad程序所在域名 *", max_length=100)
    sameItemInterval = forms.IntegerField(label="同一条目禁止多次发送的间隔(小时) *")


class ForbiddenForm(forms.Form):
    keywords = forms.CharField(
        label="请输入屏蔽词，一次可以提交多个词语，每个词语输入后请回车使词语进入候选区，不回车确认的词语不会被提交（！）", max_length=400,
        widget=forms.TextInput(attrs=
                               {'data-role': "tagsinput",
                                'placeholder': "输入关键词",
                                }))



# -*- coding: utf-8 -*-
from celery import Celery
from celery.schedules import crontab

CELERYBEAT_SCHEDULE = {
    'send-every-20-mins-in-day': {
        'task': 'moedjpack.moepad.mptask.send',
        'schedule': crontab(hour='0-15,22-0', minute='10,30,50'),
        'args': None,
    },
    'send-once-an-hour-in-night': {
        'task': 'moedjpack.moepad.mptask.send',
        'schedule': crontab(hour='16-22', minute='10'),
        'args': None,
    },
    'update-every-20-mins': {
        'task': 'moedjpack.moepad.mptask.updateitem',
        'schedule': crontab(minute='*'),
        'args': None,
    },
    # 'test': {
    #     'task': 'moedjpack.moepad.mptask.justtest',
    #     'schedule': crontab(hour='0-15,22-0', minute='*'),
    #     'args': None,
    # },
    # 'nighttest': {
    #     'task': 'moedjpack.moepad.mptask.nighttest',
    #     'schedule': crontab(hour='16-22', minute='*/2'),
    #     'args': None,
    # },
}

CELERY_TIMEZONE = 'UTC'

app = Celery('moedjpack.moepad', broker='redis://localhost/1',
             include=['moedjpack.moepad.mptask'])
app.conf.update(CELERYBEAT_SCHEDULE=CELERYBEAT_SCHEDULE, CELERY_TIMEZONE=CELERY_TIMEZONE)


if __name__ == '__main__':
    app.start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author: Sai
# @Date:   2014-02-12 23:13:59
# @Email:  email@example.com
# @Last modified by:   Sai
# @Last modified time: 2014-03-02 16:54:32
# 🎵 ミライナイト
import redis
import logging
import logging.handlers
import pytz
import os
import os.path as p
import logging.config
from datetime import datetime
from moedjpack.moedj.settings import LOGGING

rs = redis.Redis("localhost", db=1)
logging.config.dictConfig(LOGGING)
logger = logging.getLogger('moepad')


def sub_dict(somedict, somekeys, default=None):
    return dict([(k, somedict.get(k, default)) for k in somekeys])


def loggerInit(logfile):
    logger = logging.getLogger(logfile)
    logger.setLevel(logging.DEBUG)
    try:
        fh = logging.handlers.RotatingFileHandler(
            logfile, maxBytes=10*1024*1024, backupCount=2)
    except IOError:
        os.makedirs(p.dirname(logfile))
        fh = logging.handlers.RotatingFileHandler(
            logfile, maxBytes=10*1024*1024, backupCount=2)
    fh.setLevel(logging.DEBUG)
    formatter = logging.Formatter('%(asctime)s - %(message)s')
    fh.setFormatter(formatter)
    logger.addHandler(fh)
    return logger


def utcnow():
    tz = pytz.timezone('UTC')
    return datetime.now(tz)


def _deletePrefix(key):
    keys_with_prefix = rs.keys(key+"*")
    for key_with_prefix in keys_with_prefix:
        rs.delete(key_with_prefix)


def create_default_db():
    cmd = "mpserver syncdb --noinput"
    os.system(cmd)
    print("---------------------------------------")
    print("input password for user moepad[default]")
    cmd = 'mpserver createsuperuser --username=moepad --email=deloeating@gmail.com'
    os.system(cmd)



#!/usr/bin/env python
import os
import sys


def main():
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "moedjpack.moedj.settings")
    from django.core.management import execute_from_command_line

    if (len(sys.argv) == 2) and (sys.argv[1] == 'run'):
        execute_from_command_line(sys.argv[:1]+["runserver", "0.0.0.0:8090"])
    else:
        execute_from_command_line(sys.argv)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author: delo
# @Date:   2014-02-18 00:12:46
# @Email:  deloeating@gmail.com
# @Last modified by:   delo
# @Last modified time: 2014-02-19 23:44:23
import weibo
from mputils import sub_dict, rs


class WeiboApi(object):

    def __init__(self, appkey, appsecret, callback, token, expires_in):
        super(WeiboApi, self).__init__()
        self.client = weibo.APIClient(appkey, appsecret, callback)
        self.client.set_access_token(token, expires_in)

    def send(self, text, url, img=None):
        short_link = self.client.short_url__shorten(url_long=url)
        shortUrl = short_link["urls"][0]["url_short"]
        text = ' '.join([text, shortUrl])

        if img:
            with open('tmp.jpg', 'rb') as fpic:
                r = self.client.statuses.upload.post(status=text, pic=fpic)
        else:
            r = self.client.statuses.update.post(status=text)


class WeiboAuthInfo(object):
    def __init__(self, user_type):
        super(WeiboAuthInfo, self).__init__()
        args = locals()
        args.pop("self")
        for key in args.keys():
            setattr(self, key, args[key])

    def set(self, access_token, expires_in, user_type, uid):
        args = locals()
        args.pop("self")
        for key in args.keys():
            setattr(self, key, args[key])

    def load():
        pass

    def save(self):
        pass

    def clean(self):
        pass


class WeiboAuthInfoRedis(WeiboAuthInfo):
    def __init__(self, user_type):
        super(WeiboAuthInfoRedis, self).__init__(user_type)
        self.mckey = "WeiboAuth" + user_type

    def load(self):
        args = rs.get(self.mckey)
        if args:
            for key in args.keys():
                setattr(self, key, args[key])

    def save(self):
        print self.__dict__
        confs = sub_dict(self.__dict__,
                         ['uid', 'access_token', 'expires_in', 'user_type'])
        rs.hmset(self.mckey, confs)
        rs.expire(self.mckey, confs['expires_in'])

    def clean(self):
        rs.hdel(self.mckey)



from django.db import models


class WeiboAuth(models.Model):
    access_token = models.CharField(max_length=100)
    access_token_secret = models.CharField(max_length=100)
    expires_in = models.IntegerField()
    source = models.CharField(max_length=20)
    user_type = models.CharField(max_length=20)
    uid = models.CharField(max_length=32)

    def __unicode__(self):
        return self.access_token



from django.conf.urls import patterns, include, url
from django.contrib import admin
admin.autodiscover()
from django.http import HttpResponse
from django.contrib.auth.views import login, logout

urlpatterns = patterns(
    '',
    url(r'^admin/', include(admin.site.urls)),
    url(r'^loginSina/(\S+)/$', 'moedjpack.auth.views.loginSina'),
    url(r'^sinacallback/$', 'moedjpack.auth.views.sinacallback'),
    url(r'^re_auth_sina/$', 'moedjpack.auth.views.re_auth_sina'),
    url(r'^clean_auth/$', 'moedjpack.auth.views.clean_auth'),
    url(r'^$', 'moedjpack.moewiki.views.index'),
    url(r'^forbidden/$', 'moedjpack.moewiki.views.forbidden_proc'),
    url(r'^robots\.txt$', lambda r: HttpResponse("User-agent: *\nDisallow: /",
        mimetype="text/plain")),
    url(r'^accounts/login/', login),
    url(r'^forbidden_item/(\S+)/$', 'moedjpack.moewiki.views.forbidden_item'),
    # url(r'^verify/', 'moewiki.views.verify')
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from mpconf import MPConf

WIKIITEM_PREFIX = 'WikiItem:'
NEWITEM = WIKIITEM_PREFIX+"New:"
EDITED = WIKIITEM_PREFIX+'Edited:'
SENT = WIKIITEM_PREFIX+'Sent:'
VERIFYING_SET = 'VerifyingSet'
FORBIDDENS = "ForbiddenItems"
# the real expire time set in redis key should be a bit longer
# than the score (which represent items' expiry time) in zset, so the
# verifying items can be moved to verified item list before it's infomation
# disappeared by lifetime expired
VERIFYING_EXPIRE = 3600  # 1 hours
VERIFYING_ZSET_SCORE = 1800
VERIFIED_EXPIRE = 24*3600   # 24 hours
EDITED_EXPIRE = 24*3600     # 24 hours
# according to user configuration
SENT_EXPIRE = int(MPConf.sameItemInterval)*3600
queryCategoryUrl = "http://zh.moegirl.org/api.php?format=json&action=query&prop=categories&titles=%s"
queryRedirectUrl = "http://zh.moegirl.org/api.php?format=json&action=query&prop=info&redirects&titles=%s"
queryIfExistUrl = "http://zh.moegirl.org/api.php?format=json&action=query&prop=info&titles=%s"
queryLastRevisionEditor= "http://zh.moegirl.org/api.php?format=json&action=query&prop=revisions&titles=%s"
queryWeiboId = ""
"""
{
query: {
pages: {
19312: {
pageid: 19312,
ns: 0,
title: "NTR",
revisions: [
{
revid: 238336,
parentid: 237162,
user: "肺鱼",
timestamp: "2014-04-20T13:12:26Z",
comment: "/* NTR的人们 */"
}
]
}
}
}
}
"""


from __future__ import print_function
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand
import io
import codecs
import os
import sys

here = os.path.abspath(os.path.dirname(__file__))


def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)

long_description = read('README.rst')


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        errcode = pytest.main(self.test_args)
        sys.exit(errcode)

setup(
    name='moedj',
    version='0.5.9.1',
    url='https://github.com/deloeating/moedj',
    license='MIT',
    author='delo',
    tests_require=['pytest'],
    install_requires=[
        'BeautifulSoup>=3.2.1',
        'redis>=2.8.0',
        'pytz>=2012d',
        'Django>=1.5.1',
        'pysqlite>=2.6.3',
        'requests>=2.2.1',
        'celery>=3.1.9',
        ],
    cmdclass={'test': PyTest},
    author_email='deloeating@gmail.com',
    description='A simple weibo bot for zh.moegirl.org',
    long_description=long_description,
    zip_safe=False,
    packages=find_packages("."),
    package_data={
        '': ['*.md'],
        'moedjpack': ['static/css/*.css', 'static/js/*.js',
                      'static/img/*', 'templates/*/*.html',
                      'templates/*.html'],
    },
    platforms='linux',
    entry_points={
        'console_scripts':
        ['mpserver=moedjpack.run:main',
         'mpcron=moedjpack.moepad.cron:main',
         'mpupdate=moedjpack.moepad.update:update',
         'mpsend=moedjpack.moepad.update:send',
         'delprefix=moedjpack.moepad.update:deletePrefix',
         'mplog=moedjpack.moepad.showstatus:showlog',
         'mpverify=moedjpack.moepad.showstatus:show_verifying',
         'mpsyncdb=moedjpack.moepad.mputils:create_default_db',
         ]
    },
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX :: Linux',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        ],
    extras_require={
        'testing': ['pytest'],
    }
)
